mod bulk_rename;
mod close;
mod create;
mod hardlink;
mod hover;
mod link;
mod open;
mod paste;
mod peek;
mod quit;
mod refresh;
mod remove;
mod rename;
mod seek;
mod suspend;
mod tab_close;
mod tab_create;
mod tab_swap;
mod tab_switch;
mod unyank;
mod update_files;
mod update_mimetype;
mod update_paged;
mod update_task;
mod update_yanked;
mod yank;
